==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/help.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'help_ask_support'=>'Falls du eine weitergehende Frage unser Forum betreffend hast oder technische Probleme mit deinem Benutzerkonto hast, kannst du uns mit folgender Möglichkeit erreichen.',
'help_format_bgcolor'=>'Hintergrundfarbe',
'help_format_bold'=>'Fett',
'help_format_color'=>'Textfarbe',
'help_format_inline'=>'Inline (kein Zeilenumbruch)',
'help_format_italic'=>'Kursiv',
'help_format_size'=>'Testgröße',
'help_format_underline'=>'Unterstrichen',
'help_overview'=>'Bevor du uns direkt um Hilfe fragst, schaue bitte in der folgenden Auflistung nach. Dort werden einige Fragen bereits behandelt und falls du eine einfache Frage hast, kannst du diese direkt in einem neuen Beitrag stellen. Sofern du der Meinung bist weitergehende Hilfe zu benötigen oder dein Problem hier nicht behandelt wird, dann kannst du uns fragen (siehe rechte Seite).',
'help_popup_insert_anchor'=>'Du kannst hier einen Anker in deiner Nachricht angeben auf den du von woanders verlinkst',
'help_popup_insert_format'=>'Du kannst gesonderte Formatierungen angeben. Wähle erst den Text aus und dann füge die Formatierungsanweisungen ein.',
'help_popup_insert_link'=>'Du kannst zu einem anderen Beitrag oder einen deiner Anker verlinken',
'help_popup_insert_mail'=>'Bitte gebe die E-Mail Adresse an, die du einbinden möchtest.',
'help_popup_insert_uri'=>'Bitte gebe eine vollständige URL des Ziels an, daß du verlinken möchtest.',
'help_popup_mcp_rss'=>'Bitte gebe dein Kennwort an und füge die entstandene URL als Abonnement in dein entsprechendes Programm ein.',
'help_popup_search_user'=>'Nach Benutzernamen suchen (nutze * als Jokerzeichen)',
'help_popup_title'=>'Kleine, nützliche Helferlein',
'help_support_by_forum'=>'Bitte verfasse einen neuen Beitrag in unserem Forum. Verwende eine aussagekräftige Betreffzeile, den Präfix "Benötige Hilfe" und alle nötigen Informationen. Ein einfaches "hilf mir!!11!" wird nicht angenommen. Wir versuchen dir so schnell wie möglich zu helfen, aber habe ein wenig Geduld. Danke :)',
'help_support_by_mail'=>'Bitte sende eine E-Mail an die angegebene Adresse. Verwende eine aussagekräftige Betreffzeile und gib uns alle nötigen Informationen. Ein einfaches "hilf mir!!11!" wird nicht angenommen. Wir versuchen dir so schnell wie möglich zu helfen, aber habe ein wenig Geduld. Danke :)',
'insert'=>'Einfügen'
);
?>

==> larus_board-1.1.2.zip: larus_board-1.1.2/lb_private/lang/de/help.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009,2010 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'help_ask_support'=>'Falls du eine weitergehende Frage unser Forum betreffend hast oder technische Probleme mit deinem Benutzerkonto hast, kannst du uns mit folgender Möglichkeit erreichen.',
'help_format_bgcolor'=>'Hintergrundfarbe',
'help_format_bold'=>'Fett',
'help_format_color'=>'Textfarbe',
'help_format_inline'=>'Inline (kein Zeilenumbruch)',
'help_format_italic'=>'Kursiv',
'help_format_left'=>'Block links schwebend',
'help_format_right'=>'Block rechts schwebend',
'help_format_size'=>'Textgröße',
'help_format_underline'=>'Unterstrichen',
'help_format_width'=>'Breite',
'help_overview'=>'Bevor du uns direkt um Hilfe fragst, schaue bitte in der folgenden Auflistung nach. Dort werden einige Fragen bereits behandelt und falls du eine einfache Frage hast, kannst du diese direkt in einem neuen Beitrag stellen. Sofern du der Meinung bist weitergehende Hilfe zu benötigen oder dein Problem hier nicht behandelt wird, dann kannst du uns fragen (siehe rechte Seite).',
'help_popup_color'=>'Du kannst die Farben mischen, indem du nacheinander die drei Grundfarben anklickst. Um eine zu entfernen, wählst du im Farbkanal ganz links das Schwarz.',
'help_popup_insert_anchor'=>'Du kannst hier einen Anker in deiner Nachricht angeben auf den du von woanders verlinkst',
'help_popup_insert_format'=>'Du kannst gesonderte Formatierungen angeben. Wähle erst den Text aus und dann füge die Formatierungsanweisungen ein',
'help_popup_insert_link'=>'Du kannst zu einem anderen Beitrag oder einen deiner Anker verlinken',
'help_popup_insert_mail'=>'Bitte gebe die E-Mail Adresse an, die du einbinden möchtest',
'help_popup_insert_uri'=>'Bitte gebe eine vollständige URL des Ziels an, daß du verlinken möchtest',
'help_popup_mcp_rss'=>'Bitte gebe dein Kennwort an und füge die entstandene URL als Abonnement in dein entsprechendes Programm ein.',
'help_popup_search_tags'=>'Du kannst hier nach Stichwörtern suchen, ob es diese bereits gibt. Mit einem Klick werden sie deiner Liste hinzugefügt.',
'help_popup_search_user'=>'Nach Benutzernamen suchen (nutze * als Jokerzeichen)',
'help_popup_time'=>'Jede Zeit, die du hier einstellst, wird in Sekunden umgewandelt. Fülle die Felder aus wie du magst.',
'help_popup_title'=>'Kleine, nützliche Helferlein',
'help_support_by_forum'=>'Bitte verfasse einen neuen Beitrag in unserem Forum. Verwende eine aussagekräftige Betreffzeile, den Präfix "Benötige Hilfe" und alle nötigen Informationen. Ein einfaches "hilf mir!!11!" wird nicht angenommen. Wir versuchen dir so schnell wie möglich zu helfen, aber habe ein wenig Geduld. Danke :)',
'help_support_by_mail'=>'Bitte sende eine E-Mail an die angegebene Adresse. Verwende eine aussagekräftige Betreffzeile und gib uns alle nötigen Informationen. Ein einfaches "hilf mir!!11!" wird nicht angenommen. Wir versuchen dir so schnell wie möglich zu helfen, aber habe ein wenig Geduld. Danke :)',
'insert'=>'Einfügen'
);
?>
